Modules and Classes
===================


Object Representation
---------------------

:mod:`hgvs.edit`
^^^^^^^^^^^^^^^^

.. automodule:: hgvs.edit
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`hgvs.location`
^^^^^^^^^^^^^^^^^^^^

.. automodule:: hgvs.location
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`hgvs.posedit`
^^^^^^^^^^^^^^^^^^^^

.. automodule:: hgvs.posedit
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`hgvs.variant`
^^^^^^^^^^^^^^^^^^^

.. automodule:: hgvs.variant
    :members:
    :undoc-members:
    :show-inheritance:


Parsing
-------

:mod:`hgvs.parser`
^^^^^^^^^^^^^^^^^^

.. automodule:: hgvs.parser
    :members:
    :undoc-members:
    :show-inheritance:



Mapping
-------

:mod:`hgvs.hgvsmapper`
^^^^^^^^^^^^^^^^^^^^^^

.. automodule:: hgvs.hgvsmapper
    :members:
    :undoc-members:
    :show-inheritance:


:mod:`hgvs.intervalmapper`
^^^^^^^^^^^^^^^^^^^^^^^^^^

.. automodule:: hgvs.intervalmapper
    :members:
    :undoc-members:
    :show-inheritance:


:mod:`hgvs.projector`
^^^^^^^^^^^^^^^^^^^^^

.. automodule:: hgvs.projector
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`hgvs.transcriptmapper`
^^^^^^^^^^^^^^^^^^^^^^^^^^^^

.. automodule:: hgvs.transcriptmapper
    :members:
    :undoc-members:
    :show-inheritance:
